AuthorType enum

Parametrized values of the type attribute of the Author class

Inheritance
Available extensions

Values

other → const AuthorType

unknown type

author → const AuthorType

The author of the entry.

This is the person or organization who wrote the entry. The author of an entry may have a different name than the author of the feed. If an entry has multiple authors, then the atom:author elements should contain all of them.

contributor → const AuthorType

The person or organization who contributed to the entry.

This is similar to the atom:author element, but implies a different degree of participation. For example, a contributor might be a person who translated the entry or wrote a review of it.

editor → const AuthorType

The person or organization responsible for editorial content.

This is typically used for blogs and other editorial sites to indicate the person or organization that wrote the entry.

webMaster → const AuthorType

The person or organization responsible for technical issues relating to the feed.

This is typically used for blogs and other editorial sites to indicate the person or organization that wrote the entry.

publisher → const AuthorType

The person or organization who published the feed.

This is typically used for blogs and other editorial sites to indicate the person or organization that wrote the entry.

creator → const AuthorType

The person or organization who created the feed.

This is typically used for blogs and other editorial sites to indicate the person or organization that wrote the entry.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthorType>
A constant List of the values in this enum, in order of their declaration.